@@ -5,16 +5,16 @@
    Copyright (C) 2000 Eazel, Inc.
   
    This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
+   modify it under the terms of the GNU Library General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.
   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
+   Library General Public License for more details.
   
-   You should have received a copy of the GNU General Public
+   You should have received a copy of the GNU Library General Public
    License along with this program; if not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
@@ -104,42 +104,46 @@ eel_background_class_init (gpointer klass)
 	background_class = EEL_BACKGROUND_CLASS (klass);
 
 	signals[APPEARANCE_CHANGED] =
-		gtk_signal_new ("appearance_changed",
-				GTK_RUN_LAST | GTK_RUN_NO_RECURSE,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (EelBackgroundClass,
-						   appearance_changed),
-				gtk_marshal_VOID__VOID,
-				G_TYPE_NONE,
-				0);
+		g_signal_new ("appearance_changed",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE,
+			      G_STRUCT_OFFSET (EelBackgroundClass,
+					       appearance_changed),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE,
+			      0);
 	signals[SETTINGS_CHANGED] =
-		gtk_signal_new ("settings_changed",
-				GTK_RUN_LAST | GTK_RUN_NO_RECURSE,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (EelBackgroundClass,
-						   settings_changed),
-				gtk_marshal_VOID__VOID,
-				G_TYPE_NONE,
-				0);
+		g_signal_new ("settings_changed",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE,
+			      G_STRUCT_OFFSET (EelBackgroundClass,
+					       settings_changed),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE,
+			      0);
 	signals[IMAGE_LOADING_DONE] =
-		gtk_signal_new ("image_loading_done",
-				GTK_RUN_LAST | GTK_RUN_NO_RECURSE,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (EelBackgroundClass,
-						   image_loading_done),
-				gtk_marshal_VOID__BOOLEAN,
-				G_TYPE_NONE,
-				1,
-				G_TYPE_BOOLEAN);
+		g_signal_new ("image_loading_done",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE,
+			      G_STRUCT_OFFSET (EelBackgroundClass,
+					       image_loading_done),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__BOOLEAN,
+			      G_TYPE_NONE,
+			      1,
+			      G_TYPE_BOOLEAN);
 	signals[RESET] =
-		gtk_signal_new ("reset",
-				GTK_RUN_LAST | GTK_RUN_NO_RECURSE,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (EelBackgroundClass,
-						   reset),
-				gtk_marshal_VOID__VOID,
-				G_TYPE_NONE,
-				0);
+		g_signal_new ("reset",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE,
+			      G_STRUCT_OFFSET (EelBackgroundClass,
+					       reset),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE,
+			      0);
 
 	object_class->finalize = eel_background_finalize;
 }
@@ -219,14 +223,14 @@ eel_background_set_image_placement_no_emit (EelBackground *background,
 }
 
 void
-eel_background_set_image_placement (EelBackground *background,
-					 EelBackgroundImagePlacement new_placement)
+eel_background_set_image_placement (EelBackground              *background,
+				    EelBackgroundImagePlacement new_placement)
 {
 	if (eel_background_set_image_placement_no_emit (background, new_placement)) {
-		gtk_signal_emit (GTK_OBJECT (background),
-				 signals[SETTINGS_CHANGED]);
-		gtk_signal_emit (GTK_OBJECT (background),
-				 signals[APPEARANCE_CHANGED]);
+		g_signal_emit (G_OBJECT (background),
+			       signals[SETTINGS_CHANGED], 0);
+		g_signal_emit (G_OBJECT (background),
+			       signals[APPEARANCE_CHANGED], 0);
 	}
 }
 
@@ -746,9 +750,9 @@ eel_background_set_color (EelBackground *background,
 			       const char *color)
 {
 	if (eel_background_set_color_no_emit (background, color)) {
-		gtk_signal_emit (GTK_OBJECT (background), signals[SETTINGS_CHANGED]);
+		g_signal_emit (G_OBJECT (background), signals[SETTINGS_CHANGED], 0);
 		if (!eel_background_image_totally_obscures (background)) {
-			gtk_signal_emit (GTK_OBJECT (background), signals[APPEARANCE_CHANGED]);
+			g_signal_emit (GTK_OBJECT (background), signals[APPEARANCE_CHANGED], 0);
 		}
 	}
 }
@@ -774,11 +778,11 @@ eel_background_load_image_callback (GnomeVFSResult error,
 		background->details->image_height_unscaled = gdk_pixbuf_get_height (pixbuf);
 	}
 
-	gtk_signal_emit (GTK_OBJECT (background), signals[IMAGE_LOADING_DONE],
-			 pixbuf != NULL || background->details->image_uri == NULL);
+	g_signal_emit (G_OBJECT (background), signals[IMAGE_LOADING_DONE], 0,
+		       pixbuf != NULL || background->details->image_uri == NULL);
 
 	if (background->details->emit_after_load) {
-		gtk_signal_emit (GTK_OBJECT (background), signals[APPEARANCE_CHANGED]);
+		g_signal_emit (GTK_OBJECT (background), signals[APPEARANCE_CHANGED], 0);
 	}
 }
 
@@ -794,7 +798,7 @@ eel_background_cancel_loading_image (EelBackground *background)
 	if (eel_background_is_image_load_in_progress (background)) {
 		eel_cancel_gdk_pixbuf_load (background->details->load_image_handle);
 		background->details->load_image_handle = NULL;
-		gtk_signal_emit (GTK_OBJECT (background), signals[IMAGE_LOADING_DONE], FALSE);
+		g_signal_emit (GTK_OBJECT (background), signals[IMAGE_LOADING_DONE], 0, FALSE);
 	}
 }
 
@@ -845,7 +849,7 @@ eel_background_set_image_uri_helper (EelBackground *background,
 	eel_background_start_loading_image (background, emit_appearance_change, load_async);
 	
 	if (emit_setting_change) {
-		gtk_signal_emit (GTK_OBJECT (background), signals[SETTINGS_CHANGED]);
+		g_signal_emit (GTK_OBJECT (background), signals[SETTINGS_CHANGED], 0);
 	}
 
 	return TRUE;
@@ -866,7 +870,10 @@ eel_background_set_image_uri_sync (EelBackground *background, const char *image_
 static void
 set_image_and_color_image_loading_done_callback (EelBackground *background, gboolean successful_load, char *color)
 {
-	gtk_signal_disconnect_by_func (GTK_OBJECT (background), G_CALLBACK (set_image_and_color_image_loading_done_callback), (gpointer) color);
+	g_signal_handlers_disconnect_by_func (
+		G_OBJECT (background),
+		G_CALLBACK (set_image_and_color_image_loading_done_callback),
+		(gpointer) color);
 
 	eel_background_set_color_no_emit (background, color);
 
@@ -875,8 +882,8 @@ set_image_and_color_image_loading_done_callback (EelBackground *background, gboo
 	/* We always emit , even if the color didn't change, because the image change
 	 * relies on us doing it here.
 	 */
-	gtk_signal_emit (GTK_OBJECT (background), signals[SETTINGS_CHANGED]);
-	gtk_signal_emit (GTK_OBJECT (background), signals[APPEARANCE_CHANGED]);
+	g_signal_emit (G_OBJECT (background), signals[SETTINGS_CHANGED], 0);
+	g_signal_emit (G_OBJECT (background), signals[APPEARANCE_CHANGED], 0);
 }
 
 /* Use this fn to set both the image and color and avoid flash. The color isn't
@@ -987,7 +994,7 @@ eel_background_reset (EelBackground *background)
 {
 	g_return_if_fail (EEL_IS_BACKGROUND (background));
 
-	gtk_signal_emit (GTK_OBJECT (background), signals[RESET]);
+	g_signal_emit (GTK_OBJECT (background), signals[RESET], 0);
 }
 
 static void
@@ -1013,7 +1020,7 @@ draw_background_callback (GnomeCanvas *canvas, GdkDrawable *drawable,
 	 */
 	gc = gdk_gc_new (drawable);
 	eel_background_draw (background, drawable, gc, x, y, 0, 0, width, height);
-	gdk_gc_unref (gc);
+	g_object_unref (gc);
 
 	/* We don't want the draw from the base class to happen. */
 	g_signal_stop_emission_by_name (canvas, "draw_background");
@@ -1098,13 +1105,11 @@ eel_get_widget_background (GtkWidget *widget)
 	g_object_ref (background);
 	gtk_object_sink (GTK_OBJECT (background));
 	g_object_set_data_full (G_OBJECT (widget), "eel_background",
-				background, (GtkDestroyNotify) g_object_unref);
+				background, g_object_unref);
 
 	/* Arrange to get the signal whenever the background changes. */
-	gtk_signal_connect_object_while_alive (GTK_OBJECT (background),
-					       "appearance_changed",
-					       G_CALLBACK (eel_widget_background_changed),
-					       GTK_OBJECT (widget));
+	g_signal_connect_object (background, "appearance_changed",
+				 G_CALLBACK (eel_widget_background_changed), widget, G_CONNECT_SWAPPED);
 	eel_widget_background_changed (widget, background);
 
 	return background;
