@@ -67,7 +67,7 @@ struct IconSelectionData {
 typedef struct IconSelectionData IconSelectionData;
 
 ArtIRect
-eel_gnome_canvas_world_to_window_rectangle (const GnomeCanvas *canvas,
+eel_gnome_canvas_world_to_window_rectangle (GnomeCanvas *canvas,
 					    ArtDRect world_rect)
 {
 	double x0, y0, x1, y1;
@@ -75,11 +75,11 @@ eel_gnome_canvas_world_to_window_rectangle (const GnomeCanvas *canvas,
 
 	g_return_val_if_fail (GNOME_IS_CANVAS (canvas), eel_art_irect_empty);
 
-	gnome_canvas_world_to_window (GNOME_CANVAS (canvas),
+	gnome_canvas_world_to_window (canvas,
 				      world_rect.x0,
 				      world_rect.y0,
 				      &x0, &y0);
-	gnome_canvas_world_to_window (GNOME_CANVAS (canvas),
+	gnome_canvas_world_to_window (canvas,
 				      world_rect.x1,
 				      world_rect.y1,
 				      &x1, &y1);
@@ -93,7 +93,7 @@ eel_gnome_canvas_world_to_window_rectangle (const GnomeCanvas *canvas,
 }
 
 ArtIRect
-eel_gnome_canvas_world_to_canvas_rectangle (const GnomeCanvas *canvas,
+eel_gnome_canvas_world_to_canvas_rectangle (GnomeCanvas *canvas,
 					    ArtDRect world_rect)
 {
 	ArtIRect canvas_rect;
@@ -115,7 +115,7 @@ eel_gnome_canvas_world_to_canvas_rectangle (const GnomeCanvas *canvas,
 }
 
 ArtIRect
-eel_gnome_canvas_item_get_current_canvas_bounds (const GnomeCanvasItem *item)
+eel_gnome_canvas_item_get_current_canvas_bounds (GnomeCanvasItem *item)
 {
 	ArtIRect bounds;
 
@@ -151,13 +151,13 @@ eel_gnome_canvas_request_redraw_rectangle (GnomeCanvas *canvas,
 }
 
 ArtDRect
-eel_gnome_canvas_item_get_world_bounds (const GnomeCanvasItem *item)
+eel_gnome_canvas_item_get_world_bounds (GnomeCanvasItem *item)
 {
 	ArtDRect world_bounds;
 
 	g_return_val_if_fail (GNOME_IS_CANVAS_ITEM (item), eel_art_drect_empty);
 
-	gnome_canvas_item_get_bounds (GNOME_CANVAS_ITEM (item),
+	gnome_canvas_item_get_bounds (item,
 				      &world_bounds.x0,
 				      &world_bounds.y0,
 				      &world_bounds.x1,
@@ -175,7 +175,7 @@ eel_gnome_canvas_item_get_world_bounds (const GnomeCanvasItem *item)
 }
 
 ArtIRect
-eel_gnome_canvas_item_get_canvas_bounds (const GnomeCanvasItem *item)
+eel_gnome_canvas_item_get_canvas_bounds (GnomeCanvasItem *item)
 {
 	ArtDRect world_bounds;
 
@@ -541,7 +541,7 @@ try_terminal_command (const char *program,
 		return NULL;
 	}
 
-	program_in_path = gnome_is_program_in_path (program);
+	program_in_path = g_find_program_in_path (program);
 	if (program_in_path == NULL) {
 		return NULL;
 	}
@@ -762,6 +762,7 @@ dialog_response_callback (GtkWidget *dialog, gint response_id, IconSelectionData
 		icon_cancel_pressed (dialog, selection_data);
 		break;
 	default:
+		break;
 	}
 }
 
@@ -808,7 +809,7 @@ eel_gnome_icon_selector_new (const char *title,
 					      GTK_STOCK_OK, GTK_RESPONSE_OK,
 					      NULL);
 
-	gtk_window_set_policy (GTK_WINDOW (dialog), TRUE, TRUE, TRUE);
+	gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
 
 	icon_selection = gnome_icon_selection_new();
 
@@ -846,18 +847,15 @@ eel_gnome_icon_selector_new (const char *title,
 	
 	gnome_icon_selection_show_icons (GNOME_ICON_SELECTION (icon_selection));
 
-	gtk_signal_connect (GTK_OBJECT (dialog), "response",
-			    G_CALLBACK (dialog_response_callback),
-			    selection_data);
+	g_signal_connect (dialog, "response",
+			  G_CALLBACK (dialog_response_callback), selection_data);
 
-	gtk_signal_connect_after(GTK_OBJECT (gnome_icon_selection_get_gil (GNOME_ICON_SELECTION (selection_data->icon_selection))),
-				 "select_icon",
-				 G_CALLBACK(list_icon_selected_callback),
-				 selection_data);
+	g_signal_connect_after (gnome_icon_selection_get_gil (GNOME_ICON_SELECTION (selection_data->icon_selection)),
+				"select_icon",
+				G_CALLBACK (list_icon_selected_callback), selection_data);
 
-	gtk_signal_connect_while_alive( GTK_OBJECT (entry), "activate",
-					G_CALLBACK(entry_activated),
-					selection_data, GTK_OBJECT (file_entry));
+	g_signal_connect (entry, "activate",
+			  G_CALLBACK (entry_activated), selection_data);
 
 	return dialog;
 }
@@ -907,3 +905,63 @@ eel_gnome_canvas_item_send_behind (GnomeCanvasItem *item,
 		gnome_canvas_item_lower (item, item_position - behind_position);
 	}
 }
+
+ArtIRect
+eel_gnome_canvas_world_to_canvas_window_rectangle (GnomeCanvas *canvas,
+						   ArtDRect world_rect)
+{
+	ArtIRect window_rect;
+	
+	g_return_val_if_fail (GNOME_IS_CANVAS (canvas), eel_art_irect_empty);
+
+	eel_gnome_canvas_world_to_canvas_window (canvas,
+						 world_rect.x0, world_rect.y0,
+						 &window_rect.x0, &window_rect.y0);
+	eel_gnome_canvas_world_to_canvas_window (canvas,
+						 world_rect.x1, world_rect.y1,
+						 &window_rect.x1, &window_rect.y1);
+
+	return window_rect;
+}
+
+void
+eel_gnome_canvas_canvas_window_to_world (GnomeCanvas *canvas,
+					 int          window_x,
+					 int          window_y,
+					 double      *world_x,
+					 double      *world_y)
+{
+	int bin_window_x, bin_window_y;
+	
+	g_return_if_fail (GNOME_IS_CANVAS (canvas));
+
+	bin_window_x = window_x + gtk_adjustment_get_value (gtk_layout_get_hadjustment (GTK_LAYOUT (canvas)));
+	bin_window_y = window_y + gtk_adjustment_get_value (gtk_layout_get_vadjustment (GTK_LAYOUT (canvas)));
+
+	gnome_canvas_window_to_world (canvas,
+				      bin_window_x, bin_window_y,
+				      world_x, world_y);
+}
+
+void
+eel_gnome_canvas_world_to_canvas_window (GnomeCanvas *canvas,
+					 double       world_x,
+					 double       world_y,
+					 int         *window_x,
+					 int         *window_y)
+{
+	double bin_window_x, bin_window_y;
+
+	g_return_if_fail (GNOME_IS_CANVAS (canvas));
+
+	gnome_canvas_world_to_window (canvas,
+				      world_x, world_y,
+				      &bin_window_x, &bin_window_y);
+
+	if (window_x) {
+		*window_x = (int) bin_window_x - gtk_adjustment_get_value (gtk_layout_get_hadjustment (GTK_LAYOUT (canvas)));
+	}
+	if (window_y) {
+		*window_y = (int) bin_window_y - gtk_adjustment_get_value (gtk_layout_get_vadjustment (GTK_LAYOUT (canvas)));
+	}
+}
